# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class HSTSSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'enabled': 'bool',
        'max_age_seconds': 'int',
        'include_sub_domains': 'bool',
        'preload': 'bool'
    }

    attribute_map = {
        'enabled': 'enabled',
        'max_age_seconds': 'max_age_seconds',
        'include_sub_domains': 'include_sub_domains',
        'preload': 'preload'
    }

    def __init__(self, enabled=None, max_age_seconds=None, include_sub_domains=None, preload=None, local_vars_configuration=None):  # noqa: E501
        """HSTSSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._enabled = None
        self._max_age_seconds = None
        self._include_sub_domains = None
        self._preload = None
        self.discriminator = None

        self.enabled = enabled
        self.max_age_seconds = max_age_seconds
        self.include_sub_domains = include_sub_domains
        self.preload = preload

    @property
    def enabled(self):
        """Gets the enabled of this HSTSSettings.  # noqa: E501

        Whether or not to send the HSTS header. If disabled, any HSTS headers set by the application will be passed through unchanged.   # noqa: E501

        :return: The enabled of this HSTSSettings.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this HSTSSettings.

        Whether or not to send the HSTS header. If disabled, any HSTS headers set by the application will be passed through unchanged.   # noqa: E501

        :param enabled: The enabled of this HSTSSettings.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `enabled`, must not be `None`")  # noqa: E501

        self._enabled = enabled

    @property
    def max_age_seconds(self):
        """Gets the max_age_seconds of this HSTSSettings.  # noqa: E501

        The number of seconds for which to remember that accesses need to be over HTTPS. A value of 0 means that the browser should forget.   # noqa: E501

        :return: The max_age_seconds of this HSTSSettings.  # noqa: E501
        :rtype: int
        """
        return self._max_age_seconds

    @max_age_seconds.setter
    def max_age_seconds(self, max_age_seconds):
        """Sets the max_age_seconds of this HSTSSettings.

        The number of seconds for which to remember that accesses need to be over HTTPS. A value of 0 means that the browser should forget.   # noqa: E501

        :param max_age_seconds: The max_age_seconds of this HSTSSettings.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and max_age_seconds is None:  # noqa: E501
            raise ValueError("Invalid value for `max_age_seconds`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_age_seconds is not None and max_age_seconds < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_age_seconds`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_age_seconds = max_age_seconds

    @property
    def include_sub_domains(self):
        """Gets the include_sub_domains of this HSTSSettings.  # noqa: E501

        Whether subdomains of the Application should be included in the HSTS restriction.   # noqa: E501

        :return: The include_sub_domains of this HSTSSettings.  # noqa: E501
        :rtype: bool
        """
        return self._include_sub_domains

    @include_sub_domains.setter
    def include_sub_domains(self, include_sub_domains):
        """Sets the include_sub_domains of this HSTSSettings.

        Whether subdomains of the Application should be included in the HSTS restriction.   # noqa: E501

        :param include_sub_domains: The include_sub_domains of this HSTSSettings.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and include_sub_domains is None:  # noqa: E501
            raise ValueError("Invalid value for `include_sub_domains`, must not be `None`")  # noqa: E501

        self._include_sub_domains = include_sub_domains

    @property
    def preload(self):
        """Gets the preload of this HSTSSettings.  # noqa: E501

        Indicate to HSTS preload services that this application should be preloaded.   # noqa: E501

        :return: The preload of this HSTSSettings.  # noqa: E501
        :rtype: bool
        """
        return self._preload

    @preload.setter
    def preload(self, preload):
        """Sets the preload of this HSTSSettings.

        Indicate to HSTS preload services that this application should be preloaded.   # noqa: E501

        :param preload: The preload of this HSTSSettings.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and preload is None:  # noqa: E501
            raise ValueError("Invalid value for `preload`, must not be `None`")  # noqa: E501

        self._preload = preload

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HSTSSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HSTSSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'metadata': 'ConnectorStatsMetadata',
        'overall_status': 'str',
        'forwarder_stats': 'ServiceForwarderStatsGroup',
        'app_service_stats': 'ApplicationServiceStatsGroup',
        'share_service_stats': 'FileShareServiceStatsGroup',
        'diagnostic_stats': 'ConnectorDiagnosticStats',
        'system': 'AgentConnectorSystemStats',
        'transport': 'AgentConnectorTransportStats',
        'shares': 'AgentConnectorShareStats',
        'authz': 'AgentConnectorAuthzStats',
        'proxy': 'AgentConnectorProxyStats'
    }

    attribute_map = {
        'metadata': 'metadata',
        'overall_status': 'overall_status',
        'forwarder_stats': 'forwarder_stats',
        'app_service_stats': 'app_service_stats',
        'share_service_stats': 'share_service_stats',
        'diagnostic_stats': 'diagnostic_stats',
        'system': 'system',
        'transport': 'transport',
        'shares': 'shares',
        'authz': 'authz',
        'proxy': 'proxy'
    }

    def __init__(self, metadata=None, overall_status=None, forwarder_stats=None, app_service_stats=None, share_service_stats=None, diagnostic_stats=None, system=None, transport=None, shares=None, authz=None, proxy=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._metadata = None
        self._overall_status = None
        self._forwarder_stats = None
        self._app_service_stats = None
        self._share_service_stats = None
        self._diagnostic_stats = None
        self._system = None
        self._transport = None
        self._shares = None
        self._authz = None
        self._proxy = None
        self.discriminator = None

        self.metadata = metadata
        self.overall_status = overall_status
        if forwarder_stats is not None:
            self.forwarder_stats = forwarder_stats
        if app_service_stats is not None:
            self.app_service_stats = app_service_stats
        if share_service_stats is not None:
            self.share_service_stats = share_service_stats
        if diagnostic_stats is not None:
            self.diagnostic_stats = diagnostic_stats
        self.system = system
        self.transport = transport
        if shares is not None:
            self.shares = shares
        if authz is not None:
            self.authz = authz
        if proxy is not None:
            self.proxy = proxy

    @property
    def metadata(self):
        """Gets the metadata of this AgentConnectorStats.  # noqa: E501


        :return: The metadata of this AgentConnectorStats.  # noqa: E501
        :rtype: ConnectorStatsMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this AgentConnectorStats.


        :param metadata: The metadata of this AgentConnectorStats.  # noqa: E501
        :type: ConnectorStatsMetadata
        """
        if self.local_vars_configuration.client_side_validation and metadata is None:  # noqa: E501
            raise ValueError("Invalid value for `metadata`, must not be `None`")  # noqa: E501

        self._metadata = metadata

    @property
    def overall_status(self):
        """Gets the overall_status of this AgentConnectorStats.  # noqa: E501

        The summary status of the Connector. - A `good` status means that no action is neccessary on this Connector - A `warn` status means that there is an issue that should be dealt with   Examples include connections restarting frequently. - A `down` status indicates that there is a service accessibility problem   that should be dealt with as soon as possible. This could mean that there is a   problem with the Connector's configuration, or the platform. - A `stale` status indicates that although there may not be anything wrong,   we haven't been able to update the status recently. This may indicate   a communications issue between Agilicus and the Connector.   # noqa: E501

        :return: The overall_status of this AgentConnectorStats.  # noqa: E501
        :rtype: str
        """
        return self._overall_status

    @overall_status.setter
    def overall_status(self, overall_status):
        """Sets the overall_status of this AgentConnectorStats.

        The summary status of the Connector. - A `good` status means that no action is neccessary on this Connector - A `warn` status means that there is an issue that should be dealt with   Examples include connections restarting frequently. - A `down` status indicates that there is a service accessibility problem   that should be dealt with as soon as possible. This could mean that there is a   problem with the Connector's configuration, or the platform. - A `stale` status indicates that although there may not be anything wrong,   we haven't been able to update the status recently. This may indicate   a communications issue between Agilicus and the Connector.   # noqa: E501

        :param overall_status: The overall_status of this AgentConnectorStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and overall_status is None:  # noqa: E501
            raise ValueError("Invalid value for `overall_status`, must not be `None`")  # noqa: E501
        allowed_values = ["good", "warn", "down", "stale"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and overall_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `overall_status` ({0}), must be one of {1}"  # noqa: E501
                .format(overall_status, allowed_values)
            )

        self._overall_status = overall_status

    @property
    def forwarder_stats(self):
        """Gets the forwarder_stats of this AgentConnectorStats.  # noqa: E501


        :return: The forwarder_stats of this AgentConnectorStats.  # noqa: E501
        :rtype: ServiceForwarderStatsGroup
        """
        return self._forwarder_stats

    @forwarder_stats.setter
    def forwarder_stats(self, forwarder_stats):
        """Sets the forwarder_stats of this AgentConnectorStats.


        :param forwarder_stats: The forwarder_stats of this AgentConnectorStats.  # noqa: E501
        :type: ServiceForwarderStatsGroup
        """

        self._forwarder_stats = forwarder_stats

    @property
    def app_service_stats(self):
        """Gets the app_service_stats of this AgentConnectorStats.  # noqa: E501


        :return: The app_service_stats of this AgentConnectorStats.  # noqa: E501
        :rtype: ApplicationServiceStatsGroup
        """
        return self._app_service_stats

    @app_service_stats.setter
    def app_service_stats(self, app_service_stats):
        """Sets the app_service_stats of this AgentConnectorStats.


        :param app_service_stats: The app_service_stats of this AgentConnectorStats.  # noqa: E501
        :type: ApplicationServiceStatsGroup
        """

        self._app_service_stats = app_service_stats

    @property
    def share_service_stats(self):
        """Gets the share_service_stats of this AgentConnectorStats.  # noqa: E501


        :return: The share_service_stats of this AgentConnectorStats.  # noqa: E501
        :rtype: FileShareServiceStatsGroup
        """
        return self._share_service_stats

    @share_service_stats.setter
    def share_service_stats(self, share_service_stats):
        """Sets the share_service_stats of this AgentConnectorStats.


        :param share_service_stats: The share_service_stats of this AgentConnectorStats.  # noqa: E501
        :type: FileShareServiceStatsGroup
        """

        self._share_service_stats = share_service_stats

    @property
    def diagnostic_stats(self):
        """Gets the diagnostic_stats of this AgentConnectorStats.  # noqa: E501


        :return: The diagnostic_stats of this AgentConnectorStats.  # noqa: E501
        :rtype: ConnectorDiagnosticStats
        """
        return self._diagnostic_stats

    @diagnostic_stats.setter
    def diagnostic_stats(self, diagnostic_stats):
        """Sets the diagnostic_stats of this AgentConnectorStats.


        :param diagnostic_stats: The diagnostic_stats of this AgentConnectorStats.  # noqa: E501
        :type: ConnectorDiagnosticStats
        """

        self._diagnostic_stats = diagnostic_stats

    @property
    def system(self):
        """Gets the system of this AgentConnectorStats.  # noqa: E501


        :return: The system of this AgentConnectorStats.  # noqa: E501
        :rtype: AgentConnectorSystemStats
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this AgentConnectorStats.


        :param system: The system of this AgentConnectorStats.  # noqa: E501
        :type: AgentConnectorSystemStats
        """
        if self.local_vars_configuration.client_side_validation and system is None:  # noqa: E501
            raise ValueError("Invalid value for `system`, must not be `None`")  # noqa: E501

        self._system = system

    @property
    def transport(self):
        """Gets the transport of this AgentConnectorStats.  # noqa: E501


        :return: The transport of this AgentConnectorStats.  # noqa: E501
        :rtype: AgentConnectorTransportStats
        """
        return self._transport

    @transport.setter
    def transport(self, transport):
        """Sets the transport of this AgentConnectorStats.


        :param transport: The transport of this AgentConnectorStats.  # noqa: E501
        :type: AgentConnectorTransportStats
        """
        if self.local_vars_configuration.client_side_validation and transport is None:  # noqa: E501
            raise ValueError("Invalid value for `transport`, must not be `None`")  # noqa: E501

        self._transport = transport

    @property
    def shares(self):
        """Gets the shares of this AgentConnectorStats.  # noqa: E501


        :return: The shares of this AgentConnectorStats.  # noqa: E501
        :rtype: AgentConnectorShareStats
        """
        return self._shares

    @shares.setter
    def shares(self, shares):
        """Sets the shares of this AgentConnectorStats.


        :param shares: The shares of this AgentConnectorStats.  # noqa: E501
        :type: AgentConnectorShareStats
        """

        self._shares = shares

    @property
    def authz(self):
        """Gets the authz of this AgentConnectorStats.  # noqa: E501


        :return: The authz of this AgentConnectorStats.  # noqa: E501
        :rtype: AgentConnectorAuthzStats
        """
        return self._authz

    @authz.setter
    def authz(self, authz):
        """Sets the authz of this AgentConnectorStats.


        :param authz: The authz of this AgentConnectorStats.  # noqa: E501
        :type: AgentConnectorAuthzStats
        """

        self._authz = authz

    @property
    def proxy(self):
        """Gets the proxy of this AgentConnectorStats.  # noqa: E501


        :return: The proxy of this AgentConnectorStats.  # noqa: E501
        :rtype: AgentConnectorProxyStats
        """
        return self._proxy

    @proxy.setter
    def proxy(self, proxy):
        """Sets the proxy of this AgentConnectorStats.


        :param proxy: The proxy of this AgentConnectorStats.  # noqa: E501
        :type: AgentConnectorProxyStats
        """

        self._proxy = proxy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorStats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class UserIdentity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'type': 'str',
        'upstream_user_identities': 'list[UpstreamUserIdentity]'
    }

    attribute_map = {
        'id': 'id',
        'first_name': 'first_name',
        'last_name': 'last_name',
        'email': 'email',
        'type': 'type',
        'upstream_user_identities': 'upstream_user_identities'
    }

    discriminator_value_class_map = {
        'GroupMember': 'GroupMember'
    }

    def __init__(self, id=None, first_name=None, last_name=None, email=None, type=None, upstream_user_identities=None, local_vars_configuration=None):  # noqa: E501
        """UserIdentity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._type = None
        self._upstream_user_identities = None
        self.discriminator = 'type'

        if id is not None:
            self.id = id
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email is not None:
            self.email = email
        if type is not None:
            self.type = type
        if upstream_user_identities is not None:
            self.upstream_user_identities = upstream_user_identities

    @property
    def id(self):
        """Gets the id of this UserIdentity.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The id of this UserIdentity.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserIdentity.

        Unique identifier  # noqa: E501

        :param id: The id of this UserIdentity.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def first_name(self):
        """Gets the first_name of this UserIdentity.  # noqa: E501

        User's first name  # noqa: E501

        :return: The first_name of this UserIdentity.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this UserIdentity.

        User's first name  # noqa: E501

        :param first_name: The first_name of this UserIdentity.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                first_name is not None and len(first_name) > 100):
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                first_name is not None and len(first_name) < 1):
            raise ValueError("Invalid value for `first_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this UserIdentity.  # noqa: E501

        User's last name  # noqa: E501

        :return: The last_name of this UserIdentity.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this UserIdentity.

        User's last name  # noqa: E501

        :param last_name: The last_name of this UserIdentity.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                last_name is not None and len(last_name) > 100):
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                last_name is not None and len(last_name) < 0):
            raise ValueError("Invalid value for `last_name`, length must be greater than or equal to `0`")  # noqa: E501

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this UserIdentity.  # noqa: E501

        User's email address  # noqa: E501

        :return: The email of this UserIdentity.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserIdentity.

        User's email address  # noqa: E501

        :param email: The email of this UserIdentity.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 100):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) < 0):
            raise ValueError("Invalid value for `email`, length must be greater than or equal to `0`")  # noqa: E501

        self._email = email

    @property
    def type(self):
        """Gets the type of this UserIdentity.  # noqa: E501

        Type of user  # noqa: E501

        :return: The type of this UserIdentity.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UserIdentity.

        Type of user  # noqa: E501

        :param type: The type of this UserIdentity.  # noqa: E501
        :type: str
        """
        allowed_values = ["user", "group", "sysgroup", "bigroup", "service_account"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def upstream_user_identities(self):
        """Gets the upstream_user_identities of this UserIdentity.  # noqa: E501

        The upstream identities this user can use to log in to the system. When a user logs in, their identity in this system will be determined by matching against this list. Note that this implies that entries in this list are globally unique.   # noqa: E501

        :return: The upstream_user_identities of this UserIdentity.  # noqa: E501
        :rtype: list[UpstreamUserIdentity]
        """
        return self._upstream_user_identities

    @upstream_user_identities.setter
    def upstream_user_identities(self, upstream_user_identities):
        """Sets the upstream_user_identities of this UserIdentity.

        The upstream identities this user can use to log in to the system. When a user logs in, their identity in this system will be determined by matching against this list. Note that this implies that entries in this list are globally unique.   # noqa: E501

        :param upstream_user_identities: The upstream_user_identities of this UserIdentity.  # noqa: E501
        :type: list[UpstreamUserIdentity]
        """

        self._upstream_user_identities = upstream_user_identities

    def get_real_child_model(self, data):
        """Returns the real base class specified by the discriminator"""
        discriminator_key = self.attribute_map[self.discriminator]
        discriminator_value = data[discriminator_key]
        return self.discriminator_value_class_map.get(discriminator_value)

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserIdentity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserIdentity):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class Rule(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'host': 'str',
        'name': 'str',
        'method': 'str',
        'path': 'str',
        'query_parameters': 'list[RuleQueryParameter]',
        'body': 'RuleQueryBody'
    }

    attribute_map = {
        'host': 'host',
        'name': 'name',
        'method': 'method',
        'path': 'path',
        'query_parameters': 'query_parameters',
        'body': 'body'
    }

    def __init__(self, host=None, name=None, method=None, path=None, query_parameters=None, body=None, local_vars_configuration=None):  # noqa: E501
        """Rule - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._host = None
        self._name = None
        self._method = None
        self._path = None
        self._query_parameters = None
        self._body = None
        self.discriminator = None

        if host is not None:
            self.host = host
        self.name = name
        self.method = method
        self.path = path
        if query_parameters is not None:
            self.query_parameters = query_parameters
        if body is not None:
            self.body = body

    @property
    def host(self):
        """Gets the host of this Rule.  # noqa: E501

        hostname to apply authz rule to. Deprecated. This is now inferred from the Environment or Service to which the rule belongs.   # noqa: E501

        :return: The host of this Rule.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this Rule.

        hostname to apply authz rule to. Deprecated. This is now inferred from the Environment or Service to which the rule belongs.   # noqa: E501

        :param host: The host of this Rule.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def name(self):
        """Gets the name of this Rule.  # noqa: E501

        A meaningful name to help identifiy the rule. This may be used to refer to it elsewhere, or to at a glace understand its purpose.   # noqa: E501

        :return: The name of this Rule.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Rule.

        A meaningful name to help identifiy the rule. This may be used to refer to it elsewhere, or to at a glace understand its purpose.   # noqa: E501

        :param name: The name of this Rule.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def method(self):
        """Gets the method of this Rule.  # noqa: E501

        The HTTP method to allow.  # noqa: E501

        :return: The method of this Rule.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this Rule.

        The HTTP method to allow.  # noqa: E501

        :param method: The method of this Rule.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and method is None:  # noqa: E501
            raise ValueError("Invalid value for `method`, must not be `None`")  # noqa: E501
        allowed_values = ["get", "put", "post", "delete", "head", "options", "connect", "trace", "patch", "copy", "lock", "mkcol", "move", "propfind", "proppatch", "unlock", "all"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and method not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                .format(method, allowed_values)
            )

        self._method = method

    @property
    def path(self):
        """Gets the path of this Rule.  # noqa: E501

        regex for HTTP path. Can be templatized with jinja2 using definitions collection.  # noqa: E501

        :return: The path of this Rule.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this Rule.

        regex for HTTP path. Can be templatized with jinja2 using definitions collection.  # noqa: E501

        :param path: The path of this Rule.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and path is None:  # noqa: E501
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def query_parameters(self):
        """Gets the query_parameters of this Rule.  # noqa: E501

        A set of constraints on the parameters specified in the query string.  # noqa: E501

        :return: The query_parameters of this Rule.  # noqa: E501
        :rtype: list[RuleQueryParameter]
        """
        return self._query_parameters

    @query_parameters.setter
    def query_parameters(self, query_parameters):
        """Sets the query_parameters of this Rule.

        A set of constraints on the parameters specified in the query string.  # noqa: E501

        :param query_parameters: The query_parameters of this Rule.  # noqa: E501
        :type: list[RuleQueryParameter]
        """

        self._query_parameters = query_parameters

    @property
    def body(self):
        """Gets the body of this Rule.  # noqa: E501


        :return: The body of this Rule.  # noqa: E501
        :rtype: RuleQueryBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this Rule.


        :param body: The body of this Rule.  # noqa: E501
        :type: RuleQueryBody
        """

        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Rule):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Rule):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class ListSessionsResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sessions': 'list[Session]',
        'limit': 'int',
        'previous_created_time': 'datetime',
        'next_created_time': 'datetime',
        'previous_user_id': 'str',
        'next_user_id': 'str'
    }

    attribute_map = {
        'sessions': 'sessions',
        'limit': 'limit',
        'previous_created_time': 'previous_created_time',
        'next_created_time': 'next_created_time',
        'previous_user_id': 'previous_user_id',
        'next_user_id': 'next_user_id'
    }

    def __init__(self, sessions=None, limit=None, previous_created_time=None, next_created_time=None, previous_user_id=None, next_user_id=None, local_vars_configuration=None):  # noqa: E501
        """ListSessionsResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sessions = None
        self._limit = None
        self._previous_created_time = None
        self._next_created_time = None
        self._previous_user_id = None
        self._next_user_id = None
        self.discriminator = None

        self.sessions = sessions
        self.limit = limit
        if previous_created_time is not None:
            self.previous_created_time = previous_created_time
        if next_created_time is not None:
            self.next_created_time = next_created_time
        if previous_user_id is not None:
            self.previous_user_id = previous_user_id
        if next_user_id is not None:
            self.next_user_id = next_user_id

    @property
    def sessions(self):
        """Gets the sessions of this ListSessionsResponse.  # noqa: E501

        The matching Session objects  # noqa: E501

        :return: The sessions of this ListSessionsResponse.  # noqa: E501
        :rtype: list[Session]
        """
        return self._sessions

    @sessions.setter
    def sessions(self, sessions):
        """Sets the sessions of this ListSessionsResponse.

        The matching Session objects  # noqa: E501

        :param sessions: The sessions of this ListSessionsResponse.  # noqa: E501
        :type: list[Session]
        """
        if self.local_vars_configuration.client_side_validation and sessions is None:  # noqa: E501
            raise ValueError("Invalid value for `sessions`, must not be `None`")  # noqa: E501

        self._sessions = sessions

    @property
    def limit(self):
        """Gets the limit of this ListSessionsResponse.  # noqa: E501

        Limit on the number of rows in the response  # noqa: E501

        :return: The limit of this ListSessionsResponse.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListSessionsResponse.

        Limit on the number of rows in the response  # noqa: E501

        :param limit: The limit of this ListSessionsResponse.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and limit is None:  # noqa: E501
            raise ValueError("Invalid value for `limit`, must not be `None`")  # noqa: E501

        self._limit = limit

    @property
    def previous_created_time(self):
        """Gets the previous_created_time of this ListSessionsResponse.  # noqa: E501

        The earliest created time on the current page. A value of \"\" is the start of the first page. This is typically combined with other pagination parameters to sub-paginate data that has too many results for the primary pagination key.   # noqa: E501

        :return: The previous_created_time of this ListSessionsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._previous_created_time

    @previous_created_time.setter
    def previous_created_time(self, previous_created_time):
        """Sets the previous_created_time of this ListSessionsResponse.

        The earliest created time on the current page. A value of \"\" is the start of the first page. This is typically combined with other pagination parameters to sub-paginate data that has too many results for the primary pagination key.   # noqa: E501

        :param previous_created_time: The previous_created_time of this ListSessionsResponse.  # noqa: E501
        :type: datetime
        """

        self._previous_created_time = previous_created_time

    @property
    def next_created_time(self):
        """Gets the next_created_time of this ListSessionsResponse.  # noqa: E501

        The earliest created time on the next page.  This is typically combined with other pagination parameters to sub-paginate data that has too many results for the primary pagination key.   # noqa: E501

        :return: The next_created_time of this ListSessionsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._next_created_time

    @next_created_time.setter
    def next_created_time(self, next_created_time):
        """Sets the next_created_time of this ListSessionsResponse.

        The earliest created time on the next page.  This is typically combined with other pagination parameters to sub-paginate data that has too many results for the primary pagination key.   # noqa: E501

        :param next_created_time: The next_created_time of this ListSessionsResponse.  # noqa: E501
        :type: datetime
        """

        self._next_created_time = next_created_time

    @property
    def previous_user_id(self):
        """Gets the previous_user_id of this ListSessionsResponse.  # noqa: E501

        The first user_id on the current page. A value of \"\" is the start of the first page.  # noqa: E501

        :return: The previous_user_id of this ListSessionsResponse.  # noqa: E501
        :rtype: str
        """
        return self._previous_user_id

    @previous_user_id.setter
    def previous_user_id(self, previous_user_id):
        """Sets the previous_user_id of this ListSessionsResponse.

        The first user_id on the current page. A value of \"\" is the start of the first page.  # noqa: E501

        :param previous_user_id: The previous_user_id of this ListSessionsResponse.  # noqa: E501
        :type: str
        """

        self._previous_user_id = previous_user_id

    @property
    def next_user_id(self):
        """Gets the next_user_id of this ListSessionsResponse.  # noqa: E501

        The first user_id on the next page.  # noqa: E501

        :return: The next_user_id of this ListSessionsResponse.  # noqa: E501
        :rtype: str
        """
        return self._next_user_id

    @next_user_id.setter
    def next_user_id(self, next_user_id):
        """Sets the next_user_id of this ListSessionsResponse.

        The first user_id on the next page.  # noqa: E501

        :param next_user_id: The next_user_id of this ListSessionsResponse.  # noqa: E501
        :type: str
        """

        self._next_user_id = next_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSessionsResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListSessionsResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class ResourceStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'resource_id': 'str',
        'metadata': 'ResourceStatsMetadata',
        'overall_status': 'str',
        'last_warning_message': 'str',
        'session_stats': 'ResourceSessionStats'
    }

    attribute_map = {
        'resource_id': 'resource_id',
        'metadata': 'metadata',
        'overall_status': 'overall_status',
        'last_warning_message': 'last_warning_message',
        'session_stats': 'session_stats'
    }

    def __init__(self, resource_id=None, metadata=None, overall_status=None, last_warning_message=None, session_stats=None, local_vars_configuration=None):  # noqa: E501
        """ResourceStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._resource_id = None
        self._metadata = None
        self._overall_status = None
        self._last_warning_message = None
        self._session_stats = None
        self.discriminator = None

        if resource_id is not None:
            self.resource_id = resource_id
        if metadata is not None:
            self.metadata = metadata
        if overall_status is not None:
            self.overall_status = overall_status
        if last_warning_message is not None:
            self.last_warning_message = last_warning_message
        if session_stats is not None:
            self.session_stats = session_stats

    @property
    def resource_id(self):
        """Gets the resource_id of this ResourceStats.  # noqa: E501

        The unique ID of the resource. The id is provided here so that a list of resource stats can be POSTed in a single request.   # noqa: E501

        :return: The resource_id of this ResourceStats.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this ResourceStats.

        The unique ID of the resource. The id is provided here so that a list of resource stats can be POSTed in a single request.   # noqa: E501

        :param resource_id: The resource_id of this ResourceStats.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    @property
    def metadata(self):
        """Gets the metadata of this ResourceStats.  # noqa: E501


        :return: The metadata of this ResourceStats.  # noqa: E501
        :rtype: ResourceStatsMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this ResourceStats.


        :param metadata: The metadata of this ResourceStats.  # noqa: E501
        :type: ResourceStatsMetadata
        """

        self._metadata = metadata

    @property
    def overall_status(self):
        """Gets the overall_status of this ResourceStats.  # noqa: E501

        The summary status of the Resource. - A `good` status means that no action is neccessary on this Resource  - A `warn` status means that there is an issue that should be dealt with   Examples include a forwarder resource that cannot bind to the provisioned port (eg. permission   issue binding to port 80) - A `down` status indicates that there is a service accessibility problem   that should be dealt with as soon as possible. This could mean that there is a   problem with the Resource's configuration, or the platform. - A `stale` status indicates that although there may not be anything wrong,   we haven't been able to update the status recently. This may indicate   a communications issue between Agilicus and the Connector containing the resource.   # noqa: E501

        :return: The overall_status of this ResourceStats.  # noqa: E501
        :rtype: str
        """
        return self._overall_status

    @overall_status.setter
    def overall_status(self, overall_status):
        """Sets the overall_status of this ResourceStats.

        The summary status of the Resource. - A `good` status means that no action is neccessary on this Resource  - A `warn` status means that there is an issue that should be dealt with   Examples include a forwarder resource that cannot bind to the provisioned port (eg. permission   issue binding to port 80) - A `down` status indicates that there is a service accessibility problem   that should be dealt with as soon as possible. This could mean that there is a   problem with the Resource's configuration, or the platform. - A `stale` status indicates that although there may not be anything wrong,   we haven't been able to update the status recently. This may indicate   a communications issue between Agilicus and the Connector containing the resource.   # noqa: E501

        :param overall_status: The overall_status of this ResourceStats.  # noqa: E501
        :type: str
        """

        self._overall_status = overall_status

    @property
    def last_warning_message(self):
        """Gets the last_warning_message of this ResourceStats.  # noqa: E501

        A message pertaining to the last warning associated with the resource. This message is persistent in that it will remain when the status goes to `good`.   # noqa: E501

        :return: The last_warning_message of this ResourceStats.  # noqa: E501
        :rtype: str
        """
        return self._last_warning_message

    @last_warning_message.setter
    def last_warning_message(self, last_warning_message):
        """Sets the last_warning_message of this ResourceStats.

        A message pertaining to the last warning associated with the resource. This message is persistent in that it will remain when the status goes to `good`.   # noqa: E501

        :param last_warning_message: The last_warning_message of this ResourceStats.  # noqa: E501
        :type: str
        """

        self._last_warning_message = last_warning_message

    @property
    def session_stats(self):
        """Gets the session_stats of this ResourceStats.  # noqa: E501


        :return: The session_stats of this ResourceStats.  # noqa: E501
        :rtype: ResourceSessionStats
        """
        return self._session_stats

    @session_stats.setter
    def session_stats(self, session_stats):
        """Sets the session_stats of this ResourceStats.


        :param session_stats: The session_stats of this ResourceStats.  # noqa: E501
        :type: ResourceSessionStats
        """

        self._session_stats = session_stats

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResourceStats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'local_authentication_enabled': 'bool',
        'connections_info': 'list[AgentConnectorConnectionInfo]',
        'allow_list': 'AllowMapCompiled',
        'authz_public_key': 'str',
        'application_service_uri': 'str',
        'tunnel_uri': 'str',
        'service_forwarders': 'list[ServiceForwarder]',
        'from_service_forwarders': 'list[ServiceForwarder]'
    }

    attribute_map = {
        'local_authentication_enabled': 'local_authentication_enabled',
        'connections_info': 'connections_info',
        'allow_list': 'allow_list',
        'authz_public_key': 'authz_public_key',
        'application_service_uri': 'application_service_uri',
        'tunnel_uri': 'tunnel_uri',
        'service_forwarders': 'service_forwarders',
        'from_service_forwarders': 'from_service_forwarders'
    }

    def __init__(self, local_authentication_enabled=None, connections_info=None, allow_list=None, authz_public_key=None, application_service_uri=None, tunnel_uri=None, service_forwarders=None, from_service_forwarders=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._local_authentication_enabled = None
        self._connections_info = None
        self._allow_list = None
        self._authz_public_key = None
        self._application_service_uri = None
        self._tunnel_uri = None
        self._service_forwarders = None
        self._from_service_forwarders = None
        self.discriminator = None

        if local_authentication_enabled is not None:
            self.local_authentication_enabled = local_authentication_enabled
        if connections_info is not None:
            self.connections_info = connections_info
        if allow_list is not None:
            self.allow_list = allow_list
        if authz_public_key is not None:
            self.authz_public_key = authz_public_key
        if application_service_uri is not None:
            self.application_service_uri = application_service_uri
        if tunnel_uri is not None:
            self.tunnel_uri = tunnel_uri
        if service_forwarders is not None:
            self.service_forwarders = service_forwarders
        if from_service_forwarders is not None:
            self.from_service_forwarders = from_service_forwarders

    @property
    def local_authentication_enabled(self):
        """Gets the local_authentication_enabled of this AgentConnectorInfo.  # noqa: E501

        Determines whether or not the agent will expose an endpoint for local authentication  # noqa: E501

        :return: The local_authentication_enabled of this AgentConnectorInfo.  # noqa: E501
        :rtype: bool
        """
        return self._local_authentication_enabled

    @local_authentication_enabled.setter
    def local_authentication_enabled(self, local_authentication_enabled):
        """Sets the local_authentication_enabled of this AgentConnectorInfo.

        Determines whether or not the agent will expose an endpoint for local authentication  # noqa: E501

        :param local_authentication_enabled: The local_authentication_enabled of this AgentConnectorInfo.  # noqa: E501
        :type: bool
        """

        self._local_authentication_enabled = local_authentication_enabled

    @property
    def connections_info(self):
        """Gets the connections_info of this AgentConnectorInfo.  # noqa: E501

        The list of connections associated with this agent  # noqa: E501

        :return: The connections_info of this AgentConnectorInfo.  # noqa: E501
        :rtype: list[AgentConnectorConnectionInfo]
        """
        return self._connections_info

    @connections_info.setter
    def connections_info(self, connections_info):
        """Sets the connections_info of this AgentConnectorInfo.

        The list of connections associated with this agent  # noqa: E501

        :param connections_info: The connections_info of this AgentConnectorInfo.  # noqa: E501
        :type: list[AgentConnectorConnectionInfo]
        """

        self._connections_info = connections_info

    @property
    def allow_list(self):
        """Gets the allow_list of this AgentConnectorInfo.  # noqa: E501


        :return: The allow_list of this AgentConnectorInfo.  # noqa: E501
        :rtype: AllowMapCompiled
        """
        return self._allow_list

    @allow_list.setter
    def allow_list(self, allow_list):
        """Sets the allow_list of this AgentConnectorInfo.


        :param allow_list: The allow_list of this AgentConnectorInfo.  # noqa: E501
        :type: AllowMapCompiled
        """

        self._allow_list = allow_list

    @property
    def authz_public_key(self):
        """Gets the authz_public_key of this AgentConnectorInfo.  # noqa: E501

        The PEM encoded public key used for validating bearer tokens  # noqa: E501

        :return: The authz_public_key of this AgentConnectorInfo.  # noqa: E501
        :rtype: str
        """
        return self._authz_public_key

    @authz_public_key.setter
    def authz_public_key(self, authz_public_key):
        """Sets the authz_public_key of this AgentConnectorInfo.

        The PEM encoded public key used for validating bearer tokens  # noqa: E501

        :param authz_public_key: The authz_public_key of this AgentConnectorInfo.  # noqa: E501
        :type: str
        """

        self._authz_public_key = authz_public_key

    @property
    def application_service_uri(self):
        """Gets the application_service_uri of this AgentConnectorInfo.  # noqa: E501

        The URI this connector will establish as the destination URI for service forwarder requests. An agent would request a certificate for the hostname provided as part of the URI for other connectors to establish a TLS connection to this connector.   # noqa: E501

        :return: The application_service_uri of this AgentConnectorInfo.  # noqa: E501
        :rtype: str
        """
        return self._application_service_uri

    @application_service_uri.setter
    def application_service_uri(self, application_service_uri):
        """Sets the application_service_uri of this AgentConnectorInfo.

        The URI this connector will establish as the destination URI for service forwarder requests. An agent would request a certificate for the hostname provided as part of the URI for other connectors to establish a TLS connection to this connector.   # noqa: E501

        :param application_service_uri: The application_service_uri of this AgentConnectorInfo.  # noqa: E501
        :type: str
        """

        self._application_service_uri = application_service_uri

    @property
    def tunnel_uri(self):
        """Gets the tunnel_uri of this AgentConnectorInfo.  # noqa: E501

        The URI this connector uses to establish its tunnels.  # noqa: E501

        :return: The tunnel_uri of this AgentConnectorInfo.  # noqa: E501
        :rtype: str
        """
        return self._tunnel_uri

    @tunnel_uri.setter
    def tunnel_uri(self, tunnel_uri):
        """Sets the tunnel_uri of this AgentConnectorInfo.

        The URI this connector uses to establish its tunnels.  # noqa: E501

        :param tunnel_uri: The tunnel_uri of this AgentConnectorInfo.  # noqa: E501
        :type: str
        """

        self._tunnel_uri = tunnel_uri

    @property
    def service_forwarders(self):
        """Gets the service_forwarders of this AgentConnectorInfo.  # noqa: E501

        The list of service forwarders associated with this connector.  # noqa: E501

        :return: The service_forwarders of this AgentConnectorInfo.  # noqa: E501
        :rtype: list[ServiceForwarder]
        """
        return self._service_forwarders

    @service_forwarders.setter
    def service_forwarders(self, service_forwarders):
        """Sets the service_forwarders of this AgentConnectorInfo.

        The list of service forwarders associated with this connector.  # noqa: E501

        :param service_forwarders: The service_forwarders of this AgentConnectorInfo.  # noqa: E501
        :type: list[ServiceForwarder]
        """

        self._service_forwarders = service_forwarders

    @property
    def from_service_forwarders(self):
        """Gets the from_service_forwarders of this AgentConnectorInfo.  # noqa: E501

        The list of service forwarders that are forwarded to this connector.  # noqa: E501

        :return: The from_service_forwarders of this AgentConnectorInfo.  # noqa: E501
        :rtype: list[ServiceForwarder]
        """
        return self._from_service_forwarders

    @from_service_forwarders.setter
    def from_service_forwarders(self, from_service_forwarders):
        """Sets the from_service_forwarders of this AgentConnectorInfo.

        The list of service forwarders that are forwarded to this connector.  # noqa: E501

        :param from_service_forwarders: The from_service_forwarders of this AgentConnectorInfo.  # noqa: E501
        :type: list[ServiceForwarder]
        """

        self._from_service_forwarders = from_service_forwarders

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class Application(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created': 'datetime',
        'id': 'str',
        'parent_id': 'str',
        'name': 'str',
        'description': 'str',
        'category': 'str',
        'image': 'str',
        'image_username': 'str',
        'image_password': 'str',
        'image_credentials_type': 'str',
        'environments': 'list[Environment]',
        'org_id': 'str',
        'contact_email': 'str',
        'monitoring_config': 'ApplicationMonitoringConfig',
        'port': 'int',
        'healthcheck_uri': 'str',
        'roles': 'RoleList',
        'definitions': 'list[Definition]',
        'assignments': 'list[ApplicationAssignment]',
        'owned': 'bool',
        'maintained': 'bool',
        'assigned': 'bool',
        'published': 'str',
        'default_role_id': 'str',
        'default_role_name': 'str',
        'icon_url': 'str',
        'updated': 'datetime',
        'location': 'str',
        'service_account_id': 'str',
        'service_account_required': 'bool',
        'application_type': 'str',
        'name_slug': 'str',
        'workload_config': 'WorkloadConfiguration'
    }

    attribute_map = {
        'created': 'created',
        'id': 'id',
        'parent_id': 'parent_id',
        'name': 'name',
        'description': 'description',
        'category': 'category',
        'image': 'image',
        'image_username': 'image_username',
        'image_password': 'image_password',
        'image_credentials_type': 'image_credentials_type',
        'environments': 'environments',
        'org_id': 'org_id',
        'contact_email': 'contact_email',
        'monitoring_config': 'monitoring_config',
        'port': 'port',
        'healthcheck_uri': 'healthcheck_uri',
        'roles': 'roles',
        'definitions': 'definitions',
        'assignments': 'assignments',
        'owned': 'owned',
        'maintained': 'maintained',
        'assigned': 'assigned',
        'published': 'published',
        'default_role_id': 'default_role_id',
        'default_role_name': 'default_role_name',
        'icon_url': 'icon_url',
        'updated': 'updated',
        'location': 'location',
        'service_account_id': 'service_account_id',
        'service_account_required': 'service_account_required',
        'application_type': 'application_type',
        'name_slug': 'name_slug',
        'workload_config': 'workload_config'
    }

    def __init__(self, created=None, id=None, parent_id=None, name=None, description=None, category=None, image=None, image_username=None, image_password=None, image_credentials_type=None, environments=None, org_id=None, contact_email=None, monitoring_config=None, port=None, healthcheck_uri=None, roles=None, definitions=None, assignments=None, owned=None, maintained=None, assigned=None, published='no', default_role_id=None, default_role_name=None, icon_url=None, updated=None, location=None, service_account_id=None, service_account_required=None, application_type='user_defined', name_slug=None, workload_config=None, local_vars_configuration=None):  # noqa: E501
        """Application - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._created = None
        self._id = None
        self._parent_id = None
        self._name = None
        self._description = None
        self._category = None
        self._image = None
        self._image_username = None
        self._image_password = None
        self._image_credentials_type = None
        self._environments = None
        self._org_id = None
        self._contact_email = None
        self._monitoring_config = None
        self._port = None
        self._healthcheck_uri = None
        self._roles = None
        self._definitions = None
        self._assignments = None
        self._owned = None
        self._maintained = None
        self._assigned = None
        self._published = None
        self._default_role_id = None
        self._default_role_name = None
        self._icon_url = None
        self._updated = None
        self._location = None
        self._service_account_id = None
        self._service_account_required = None
        self._application_type = None
        self._name_slug = None
        self._workload_config = None
        self.discriminator = None

        if created is not None:
            self.created = created
        if id is not None:
            self.id = id
        if parent_id is not None:
            self.parent_id = parent_id
        self.name = name
        if description is not None:
            self.description = description
        self.category = category
        if image is not None:
            self.image = image
        if image_username is not None:
            self.image_username = image_username
        if image_password is not None:
            self.image_password = image_password
        if image_credentials_type is not None:
            self.image_credentials_type = image_credentials_type
        if environments is not None:
            self.environments = environments
        self.org_id = org_id
        if contact_email is not None:
            self.contact_email = contact_email
        if monitoring_config is not None:
            self.monitoring_config = monitoring_config
        if port is not None:
            self.port = port
        if healthcheck_uri is not None:
            self.healthcheck_uri = healthcheck_uri
        if roles is not None:
            self.roles = roles
        if definitions is not None:
            self.definitions = definitions
        if assignments is not None:
            self.assignments = assignments
        if owned is not None:
            self.owned = owned
        if maintained is not None:
            self.maintained = maintained
        if assigned is not None:
            self.assigned = assigned
        if published is not None:
            self.published = published
        self.default_role_id = default_role_id
        self.default_role_name = default_role_name
        if icon_url is not None:
            self.icon_url = icon_url
        if updated is not None:
            self.updated = updated
        if location is not None:
            self.location = location
        if service_account_id is not None:
            self.service_account_id = service_account_id
        if service_account_required is not None:
            self.service_account_required = service_account_required
        if application_type is not None:
            self.application_type = application_type
        if name_slug is not None:
            self.name_slug = name_slug
        if workload_config is not None:
            self.workload_config = workload_config

    @property
    def created(self):
        """Gets the created of this Application.  # noqa: E501

        Creation time  # noqa: E501

        :return: The created of this Application.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Application.

        Creation time  # noqa: E501

        :param created: The created of this Application.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def id(self):
        """Gets the id of this Application.  # noqa: E501

        application service id  # noqa: E501

        :return: The id of this Application.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Application.

        application service id  # noqa: E501

        :param id: The id of this Application.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def parent_id(self):
        """Gets the parent_id of this Application.  # noqa: E501

        For inheritance, defines the parent id.  # noqa: E501

        :return: The parent_id of this Application.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this Application.

        For inheritance, defines the parent id.  # noqa: E501

        :param parent_id: The parent_id of this Application.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def name(self):
        """Gets the name of this Application.  # noqa: E501

        application name  # noqa: E501

        :return: The name of this Application.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Application.

        application name  # noqa: E501

        :param name: The name of this Application.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 63):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `63`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and not re.search(r'^[a-zA-Z0-9-:]+$', name)):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[a-zA-Z0-9-:]+$/`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this Application.  # noqa: E501

        Application description text  # noqa: E501

        :return: The description of this Application.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Application.

        Application description text  # noqa: E501

        :param description: The description of this Application.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def category(self):
        """Gets the category of this Application.  # noqa: E501

        application category  # noqa: E501

        :return: The category of this Application.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Application.

        application category  # noqa: E501

        :param category: The category of this Application.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and category is None:  # noqa: E501
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                category is not None and len(category) > 100):
            raise ValueError("Invalid value for `category`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                category is not None and len(category) < 1):
            raise ValueError("Invalid value for `category`, length must be greater than or equal to `1`")  # noqa: E501

        self._category = category

    @property
    def image(self):
        """Gets the image of this Application.  # noqa: E501

        image registry path and name  # noqa: E501

        :return: The image of this Application.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this Application.

        image registry path and name  # noqa: E501

        :param image: The image of this Application.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def image_username(self):
        """Gets the image_username of this Application.  # noqa: E501

        registry username  # noqa: E501

        :return: The image_username of this Application.  # noqa: E501
        :rtype: str
        """
        return self._image_username

    @image_username.setter
    def image_username(self, image_username):
        """Sets the image_username of this Application.

        registry username  # noqa: E501

        :param image_username: The image_username of this Application.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                image_username is not None and len(image_username) > 100):
            raise ValueError("Invalid value for `image_username`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                image_username is not None and len(image_username) < 1):
            raise ValueError("Invalid value for `image_username`, length must be greater than or equal to `1`")  # noqa: E501

        self._image_username = image_username

    @property
    def image_password(self):
        """Gets the image_password of this Application.  # noqa: E501

        registry password  # noqa: E501

        :return: The image_password of this Application.  # noqa: E501
        :rtype: str
        """
        return self._image_password

    @image_password.setter
    def image_password(self, image_password):
        """Sets the image_password of this Application.

        registry password  # noqa: E501

        :param image_password: The image_password of this Application.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                image_password is not None and len(image_password) > 100):
            raise ValueError("Invalid value for `image_password`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                image_password is not None and len(image_password) < 1):
            raise ValueError("Invalid value for `image_password`, length must be greater than or equal to `1`")  # noqa: E501

        self._image_password = image_password

    @property
    def image_credentials_type(self):
        """Gets the image_credentials_type of this Application.  # noqa: E501

        type of credentials for image  # noqa: E501

        :return: The image_credentials_type of this Application.  # noqa: E501
        :rtype: str
        """
        return self._image_credentials_type

    @image_credentials_type.setter
    def image_credentials_type(self, image_credentials_type):
        """Sets the image_credentials_type of this Application.

        type of credentials for image  # noqa: E501

        :param image_credentials_type: The image_credentials_type of this Application.  # noqa: E501
        :type: str
        """
        allowed_values = ["basic_auth", "token"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and image_credentials_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `image_credentials_type` ({0}), must be one of {1}"  # noqa: E501
                .format(image_credentials_type, allowed_values)
            )

        self._image_credentials_type = image_credentials_type

    @property
    def environments(self):
        """Gets the environments of this Application.  # noqa: E501

        List of environments  # noqa: E501

        :return: The environments of this Application.  # noqa: E501
        :rtype: list[Environment]
        """
        return self._environments

    @environments.setter
    def environments(self, environments):
        """Sets the environments of this Application.

        List of environments  # noqa: E501

        :param environments: The environments of this Application.  # noqa: E501
        :type: list[Environment]
        """

        self._environments = environments

    @property
    def org_id(self):
        """Gets the org_id of this Application.  # noqa: E501

        organisation id  # noqa: E501

        :return: The org_id of this Application.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this Application.

        organisation id  # noqa: E501

        :param org_id: The org_id of this Application.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) < 1):
            raise ValueError("Invalid value for `org_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._org_id = org_id

    @property
    def contact_email(self):
        """Gets the contact_email of this Application.  # noqa: E501

        Administrator contact email  # noqa: E501

        :return: The contact_email of this Application.  # noqa: E501
        :rtype: str
        """
        return self._contact_email

    @contact_email.setter
    def contact_email(self, contact_email):
        """Sets the contact_email of this Application.

        Administrator contact email  # noqa: E501

        :param contact_email: The contact_email of this Application.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                contact_email is not None and len(contact_email) > 100):
            raise ValueError("Invalid value for `contact_email`, length must be less than or equal to `100`")  # noqa: E501

        self._contact_email = contact_email

    @property
    def monitoring_config(self):
        """Gets the monitoring_config of this Application.  # noqa: E501


        :return: The monitoring_config of this Application.  # noqa: E501
        :rtype: ApplicationMonitoringConfig
        """
        return self._monitoring_config

    @monitoring_config.setter
    def monitoring_config(self, monitoring_config):
        """Sets the monitoring_config of this Application.


        :param monitoring_config: The monitoring_config of this Application.  # noqa: E501
        :type: ApplicationMonitoringConfig
        """

        self._monitoring_config = monitoring_config

    @property
    def port(self):
        """Gets the port of this Application.  # noqa: E501

        The transport layer port the application listens on for requests. E.g. if the application listens for HTTP requests on the standard port, port 80, set this to 80.   # noqa: E501

        :return: The port of this Application.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this Application.

        The transport layer port the application listens on for requests. E.g. if the application listens for HTTP requests on the standard port, port 80, set this to 80.   # noqa: E501

        :param port: The port of this Application.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def healthcheck_uri(self):
        """Gets the healthcheck_uri of this Application.  # noqa: E501

        health check URI  # noqa: E501

        :return: The healthcheck_uri of this Application.  # noqa: E501
        :rtype: str
        """
        return self._healthcheck_uri

    @healthcheck_uri.setter
    def healthcheck_uri(self, healthcheck_uri):
        """Sets the healthcheck_uri of this Application.

        health check URI  # noqa: E501

        :param healthcheck_uri: The healthcheck_uri of this Application.  # noqa: E501
        :type: str
        """

        self._healthcheck_uri = healthcheck_uri

    @property
    def roles(self):
        """Gets the roles of this Application.  # noqa: E501


        :return: The roles of this Application.  # noqa: E501
        :rtype: RoleList
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this Application.


        :param roles: The roles of this Application.  # noqa: E501
        :type: RoleList
        """

        self._roles = roles

    @property
    def definitions(self):
        """Gets the definitions of this Application.  # noqa: E501

        List of definitions  # noqa: E501

        :return: The definitions of this Application.  # noqa: E501
        :rtype: list[Definition]
        """
        return self._definitions

    @definitions.setter
    def definitions(self, definitions):
        """Sets the definitions of this Application.

        List of definitions  # noqa: E501

        :param definitions: The definitions of this Application.  # noqa: E501
        :type: list[Definition]
        """

        self._definitions = definitions

    @property
    def assignments(self):
        """Gets the assignments of this Application.  # noqa: E501

        Controls the Organisations which have access to Environments of this Application.   # noqa: E501

        :return: The assignments of this Application.  # noqa: E501
        :rtype: list[ApplicationAssignment]
        """
        return self._assignments

    @assignments.setter
    def assignments(self, assignments):
        """Sets the assignments of this Application.

        Controls the Organisations which have access to Environments of this Application.   # noqa: E501

        :param assignments: The assignments of this Application.  # noqa: E501
        :type: list[ApplicationAssignment]
        """

        self._assignments = assignments

    @property
    def owned(self):
        """Gets the owned of this Application.  # noqa: E501

        Whether this Application is owned by the provided organisation.   # noqa: E501

        :return: The owned of this Application.  # noqa: E501
        :rtype: bool
        """
        return self._owned

    @owned.setter
    def owned(self, owned):
        """Sets the owned of this Application.

        Whether this Application is owned by the provided organisation.   # noqa: E501

        :param owned: The owned of this Application.  # noqa: E501
        :type: bool
        """

        self._owned = owned

    @property
    def maintained(self):
        """Gets the maintained of this Application.  # noqa: E501

        Whether this Application has an Environment maintained by the provided organisation.   # noqa: E501

        :return: The maintained of this Application.  # noqa: E501
        :rtype: bool
        """
        return self._maintained

    @maintained.setter
    def maintained(self, maintained):
        """Sets the maintained of this Application.

        Whether this Application has an Environment maintained by the provided organisation.   # noqa: E501

        :param maintained: The maintained of this Application.  # noqa: E501
        :type: bool
        """

        self._maintained = maintained

    @property
    def assigned(self):
        """Gets the assigned of this Application.  # noqa: E501

        Whether an Environment is assigned to this Application.   # noqa: E501

        :return: The assigned of this Application.  # noqa: E501
        :rtype: bool
        """
        return self._assigned

    @assigned.setter
    def assigned(self, assigned):
        """Sets the assigned of this Application.

        Whether an Environment is assigned to this Application.   # noqa: E501

        :param assigned: The assigned of this Application.  # noqa: E501
        :type: bool
        """

        self._assigned = assigned

    @property
    def published(self):
        """Gets the published of this Application.  # noqa: E501

        Whether or not this Application is published, and if so, how. An application that has been published somewhere will have high level details about it visible (through apis intended to expose published applications), such as its name and description. The enum values mean the following:  - no: This application is not published. It will only be visibile to users with       permission to access the application, or to administrators.  - public: This application is published to the public catalogue. Any user who       can request access to the organisation will see high level details about this       application.   # noqa: E501

        :return: The published of this Application.  # noqa: E501
        :rtype: str
        """
        return self._published

    @published.setter
    def published(self, published):
        """Sets the published of this Application.

        Whether or not this Application is published, and if so, how. An application that has been published somewhere will have high level details about it visible (through apis intended to expose published applications), such as its name and description. The enum values mean the following:  - no: This application is not published. It will only be visibile to users with       permission to access the application, or to administrators.  - public: This application is published to the public catalogue. Any user who       can request access to the organisation will see high level details about this       application.   # noqa: E501

        :param published: The published of this Application.  # noqa: E501
        :type: str
        """
        allowed_values = ["no", "public"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and published not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `published` ({0}), must be one of {1}"  # noqa: E501
                .format(published, allowed_values)
            )

        self._published = published

    @property
    def default_role_id(self):
        """Gets the default_role_id of this Application.  # noqa: E501

        The id of the default role to use for this application. This role will be assigned to users granted access to this application by default, unless overridden. This value must point to a valid Role for this application. A string of length 0 will clear out the default role.  # noqa: E501

        :return: The default_role_id of this Application.  # noqa: E501
        :rtype: str
        """
        return self._default_role_id

    @default_role_id.setter
    def default_role_id(self, default_role_id):
        """Sets the default_role_id of this Application.

        The id of the default role to use for this application. This role will be assigned to users granted access to this application by default, unless overridden. This value must point to a valid Role for this application. A string of length 0 will clear out the default role.  # noqa: E501

        :param default_role_id: The default_role_id of this Application.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                default_role_id is not None and len(default_role_id) > 40):
            raise ValueError("Invalid value for `default_role_id`, length must be less than or equal to `40`")  # noqa: E501

        self._default_role_id = default_role_id

    @property
    def default_role_name(self):
        """Gets the default_role_name of this Application.  # noqa: E501

        The name of the default role. Does not change which role is used. Provided for convenience.   # noqa: E501

        :return: The default_role_name of this Application.  # noqa: E501
        :rtype: str
        """
        return self._default_role_name

    @default_role_name.setter
    def default_role_name(self, default_role_name):
        """Sets the default_role_name of this Application.

        The name of the default role. Does not change which role is used. Provided for convenience.   # noqa: E501

        :param default_role_name: The default_role_name of this Application.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                default_role_name is not None and len(default_role_name) > 100):
            raise ValueError("Invalid value for `default_role_name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                default_role_name is not None and len(default_role_name) < 1):
            raise ValueError("Invalid value for `default_role_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._default_role_name = default_role_name

    @property
    def icon_url(self):
        """Gets the icon_url of this Application.  # noqa: E501

        A url pointing to an icon representing this application.   # noqa: E501

        :return: The icon_url of this Application.  # noqa: E501
        :rtype: str
        """
        return self._icon_url

    @icon_url.setter
    def icon_url(self, icon_url):
        """Sets the icon_url of this Application.

        A url pointing to an icon representing this application.   # noqa: E501

        :param icon_url: The icon_url of this Application.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                icon_url is not None and len(icon_url) > 1024):
            raise ValueError("Invalid value for `icon_url`, length must be less than or equal to `1024`")  # noqa: E501

        self._icon_url = icon_url

    @property
    def updated(self):
        """Gets the updated of this Application.  # noqa: E501

        Update time  # noqa: E501

        :return: The updated of this Application.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this Application.

        Update time  # noqa: E501

        :param updated: The updated of this Application.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    @property
    def location(self):
        """Gets the location of this Application.  # noqa: E501

        Where the application runs. Applications can run within an Agilicus hosting platform, or elsewhere on the internet. The possible values have the following meanings:   - `hosted`: the application runs on the Agilicus hosting platform.   - `external`: the application runs elsewhere on the internet. External applications     will not create instances in the Agilicus hosting platform. However, they will     be able to use Agilicus for Identity and Authentication.   # noqa: E501

        :return: The location of this Application.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this Application.

        Where the application runs. Applications can run within an Agilicus hosting platform, or elsewhere on the internet. The possible values have the following meanings:   - `hosted`: the application runs on the Agilicus hosting platform.   - `external`: the application runs elsewhere on the internet. External applications     will not create instances in the Agilicus hosting platform. However, they will     be able to use Agilicus for Identity and Authentication.   # noqa: E501

        :param location: The location of this Application.  # noqa: E501
        :type: str
        """
        allowed_values = ["hosted", "external"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and location not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `location` ({0}), must be one of {1}"  # noqa: E501
                .format(location, allowed_values)
            )

        self._location = location

    @property
    def service_account_id(self):
        """Gets the service_account_id of this Application.  # noqa: E501

        Service account user GUID used to deploy the application  # noqa: E501

        :return: The service_account_id of this Application.  # noqa: E501
        :rtype: str
        """
        return self._service_account_id

    @service_account_id.setter
    def service_account_id(self, service_account_id):
        """Sets the service_account_id of this Application.

        Service account user GUID used to deploy the application  # noqa: E501

        :param service_account_id: The service_account_id of this Application.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                service_account_id is not None and len(service_account_id) > 40):
            raise ValueError("Invalid value for `service_account_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                service_account_id is not None and len(service_account_id) < 1):
            raise ValueError("Invalid value for `service_account_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._service_account_id = service_account_id

    @property
    def service_account_required(self):
        """Gets the service_account_required of this Application.  # noqa: E501

        If service_account_enabled field is set to true, a service account will be created. If service_account_enabled field is set to false, the service account will be deleted. If the service_account_enabled field is not set no action on the service account is taken.   # noqa: E501

        :return: The service_account_required of this Application.  # noqa: E501
        :rtype: bool
        """
        return self._service_account_required

    @service_account_required.setter
    def service_account_required(self, service_account_required):
        """Sets the service_account_required of this Application.

        If service_account_enabled field is set to true, a service account will be created. If service_account_enabled field is set to false, the service account will be deleted. If the service_account_enabled field is not set no action on the service account is taken.   # noqa: E501

        :param service_account_required: The service_account_required of this Application.  # noqa: E501
        :type: bool
        """

        self._service_account_required = service_account_required

    @property
    def application_type(self):
        """Gets the application_type of this Application.  # noqa: E501

        The type of application meanings:   - `user_defined`: A user defined application.   - `internal`: An internal application used by agilicus services.   # noqa: E501

        :return: The application_type of this Application.  # noqa: E501
        :rtype: str
        """
        return self._application_type

    @application_type.setter
    def application_type(self, application_type):
        """Sets the application_type of this Application.

        The type of application meanings:   - `user_defined`: A user defined application.   - `internal`: An internal application used by agilicus services.   # noqa: E501

        :param application_type: The application_type of this Application.  # noqa: E501
        :type: str
        """
        allowed_values = ["user_defined", "internal"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and application_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `application_type` ({0}), must be one of {1}"  # noqa: E501
                .format(application_type, allowed_values)
            )

        self._application_type = application_type

    @property
    def name_slug(self):
        """Gets the name_slug of this Application.  # noqa: E501

        A human readable slug to identify a resource and that is rfc1035 label compliant. The length has been restricted to 20 characters such that this name can be concatenated with other names or slugs. A slug is readOnly as it is generated by the backend resource.   # noqa: E501

        :return: The name_slug of this Application.  # noqa: E501
        :rtype: str
        """
        return self._name_slug

    @name_slug.setter
    def name_slug(self, name_slug):
        """Sets the name_slug of this Application.

        A human readable slug to identify a resource and that is rfc1035 label compliant. The length has been restricted to 20 characters such that this name can be concatenated with other names or slugs. A slug is readOnly as it is generated by the backend resource.   # noqa: E501

        :param name_slug: The name_slug of this Application.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name_slug is not None and len(name_slug) > 20):
            raise ValueError("Invalid value for `name_slug`, length must be less than or equal to `20`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name_slug is not None and not re.search(r'^[a-z]|[a-z0-9][a-z0-9\-]*[a-z0-9]$', name_slug)):  # noqa: E501
            raise ValueError(r"Invalid value for `name_slug`, must be a follow pattern or equal to `/^[a-z]|[a-z0-9][a-z0-9\-]*[a-z0-9]$/`")  # noqa: E501

        self._name_slug = name_slug

    @property
    def workload_config(self):
        """Gets the workload_config of this Application.  # noqa: E501


        :return: The workload_config of this Application.  # noqa: E501
        :rtype: WorkloadConfiguration
        """
        return self._workload_config

    @workload_config.setter
    def workload_config(self, workload_config):
        """Sets the workload_config of this Application.


        :param workload_config: The workload_config of this Application.  # noqa: E501
        :type: WorkloadConfiguration
        """

        self._workload_config = workload_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Application):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Application):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class CatalogueEntry(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'catalogue_id': 'str',
        'catalogue_category': 'str',
        'name': 'str',
        'content': 'str',
        'tag': 'str',
        'short_description': 'str',
        'long_description': 'str',
        'created': 'datetime',
        'updated': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'catalogue_id': 'catalogue_id',
        'catalogue_category': 'catalogue_category',
        'name': 'name',
        'content': 'content',
        'tag': 'tag',
        'short_description': 'short_description',
        'long_description': 'long_description',
        'created': 'created',
        'updated': 'updated'
    }

    def __init__(self, id=None, catalogue_id=None, catalogue_category=None, name=None, content=None, tag=None, short_description=None, long_description=None, created=None, updated=None, local_vars_configuration=None):  # noqa: E501
        """CatalogueEntry - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._catalogue_id = None
        self._catalogue_category = None
        self._name = None
        self._content = None
        self._tag = None
        self._short_description = None
        self._long_description = None
        self._created = None
        self._updated = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if catalogue_id is not None:
            self.catalogue_id = catalogue_id
        if catalogue_category is not None:
            self.catalogue_category = catalogue_category
        self.name = name
        if content is not None:
            self.content = content
        if tag is not None:
            self.tag = tag
        if short_description is not None:
            self.short_description = short_description
        if long_description is not None:
            self.long_description = long_description
        if created is not None:
            self.created = created
        if updated is not None:
            self.updated = updated

    @property
    def id(self):
        """Gets the id of this CatalogueEntry.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The id of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CatalogueEntry.

        Unique identifier  # noqa: E501

        :param id: The id of this CatalogueEntry.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def catalogue_id(self):
        """Gets the catalogue_id of this CatalogueEntry.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The catalogue_id of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._catalogue_id

    @catalogue_id.setter
    def catalogue_id(self, catalogue_id):
        """Sets the catalogue_id of this CatalogueEntry.

        Unique identifier  # noqa: E501

        :param catalogue_id: The catalogue_id of this CatalogueEntry.  # noqa: E501
        :type: str
        """

        self._catalogue_id = catalogue_id

    @property
    def catalogue_category(self):
        """Gets the catalogue_category of this CatalogueEntry.  # noqa: E501

        The category of catalogue that this entry is apart of  # noqa: E501

        :return: The catalogue_category of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._catalogue_category

    @catalogue_category.setter
    def catalogue_category(self, catalogue_category):
        """Sets the catalogue_category of this CatalogueEntry.

        The category of catalogue that this entry is apart of  # noqa: E501

        :param catalogue_category: The catalogue_category of this CatalogueEntry.  # noqa: E501
        :type: str
        """

        self._catalogue_category = catalogue_category

    @property
    def name(self):
        """Gets the name of this CatalogueEntry.  # noqa: E501

        The name of the catalogue entry in a user friendly form  # noqa: E501

        :return: The name of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CatalogueEntry.

        The name of the catalogue entry in a user friendly form  # noqa: E501

        :param name: The name of this CatalogueEntry.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def content(self):
        """Gets the content of this CatalogueEntry.  # noqa: E501

        The content of the catalogue  # noqa: E501

        :return: The content of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this CatalogueEntry.

        The content of the catalogue  # noqa: E501

        :param content: The content of this CatalogueEntry.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                content is not None and len(content) > 5242880):
            raise ValueError("Invalid value for `content`, length must be less than or equal to `5242880`")  # noqa: E501

        self._content = content

    @property
    def tag(self):
        """Gets the tag of this CatalogueEntry.  # noqa: E501

        A qualifier for the catalogue entry. Used for differentiating between entries of the same name  # noqa: E501

        :return: The tag of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this CatalogueEntry.

        A qualifier for the catalogue entry. Used for differentiating between entries of the same name  # noqa: E501

        :param tag: The tag of this CatalogueEntry.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                tag is not None and len(tag) > 40):
            raise ValueError("Invalid value for `tag`, length must be less than or equal to `40`")  # noqa: E501

        self._tag = tag

    @property
    def short_description(self):
        """Gets the short_description of this CatalogueEntry.  # noqa: E501

        A short description of the catalogue entry.  # noqa: E501

        :return: The short_description of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """Sets the short_description of this CatalogueEntry.

        A short description of the catalogue entry.  # noqa: E501

        :param short_description: The short_description of this CatalogueEntry.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                short_description is not None and len(short_description) > 255):
            raise ValueError("Invalid value for `short_description`, length must be less than or equal to `255`")  # noqa: E501

        self._short_description = short_description

    @property
    def long_description(self):
        """Gets the long_description of this CatalogueEntry.  # noqa: E501

        A detailed description of the catalogue entry  # noqa: E501

        :return: The long_description of this CatalogueEntry.  # noqa: E501
        :rtype: str
        """
        return self._long_description

    @long_description.setter
    def long_description(self, long_description):
        """Sets the long_description of this CatalogueEntry.

        A detailed description of the catalogue entry  # noqa: E501

        :param long_description: The long_description of this CatalogueEntry.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                long_description is not None and len(long_description) > 2000):
            raise ValueError("Invalid value for `long_description`, length must be less than or equal to `2000`")  # noqa: E501

        self._long_description = long_description

    @property
    def created(self):
        """Gets the created of this CatalogueEntry.  # noqa: E501

        Creation time  # noqa: E501

        :return: The created of this CatalogueEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this CatalogueEntry.

        Creation time  # noqa: E501

        :param created: The created of this CatalogueEntry.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this CatalogueEntry.  # noqa: E501

        Update time  # noqa: E501

        :return: The updated of this CatalogueEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this CatalogueEntry.

        Update time  # noqa: E501

        :param updated: The updated of this CatalogueEntry.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CatalogueEntry):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CatalogueEntry):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorTransportStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active_connections': 'int',
        'target_number_connections': 'int',
        'connection_start_count': 'int',
        'connection_stop_count': 'int'
    }

    attribute_map = {
        'active_connections': 'active_connections',
        'target_number_connections': 'target_number_connections',
        'connection_start_count': 'connection_start_count',
        'connection_stop_count': 'connection_stop_count'
    }

    def __init__(self, active_connections=None, target_number_connections=None, connection_start_count=None, connection_stop_count=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorTransportStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._active_connections = None
        self._target_number_connections = None
        self._connection_start_count = None
        self._connection_stop_count = None
        self.discriminator = None

        self.active_connections = active_connections
        self.target_number_connections = target_number_connections
        self.connection_start_count = connection_start_count
        self.connection_stop_count = connection_stop_count

    @property
    def active_connections(self):
        """Gets the active_connections of this AgentConnectorTransportStats.  # noqa: E501

        The number of currently active connections.   # noqa: E501

        :return: The active_connections of this AgentConnectorTransportStats.  # noqa: E501
        :rtype: int
        """
        return self._active_connections

    @active_connections.setter
    def active_connections(self, active_connections):
        """Sets the active_connections of this AgentConnectorTransportStats.

        The number of currently active connections.   # noqa: E501

        :param active_connections: The active_connections of this AgentConnectorTransportStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and active_connections is None:  # noqa: E501
            raise ValueError("Invalid value for `active_connections`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                active_connections is not None and active_connections < 0):  # noqa: E501
            raise ValueError("Invalid value for `active_connections`, must be a value greater than or equal to `0`")  # noqa: E501

        self._active_connections = active_connections

    @property
    def target_number_connections(self):
        """Gets the target_number_connections of this AgentConnectorTransportStats.  # noqa: E501

        The number of connections which should be in an active state. Note that this may be less than active_connections if the AgentConnector is currently applying configuration changes. It may be more than active_connections if there is a connectivity issue, or connections are first starting.   # noqa: E501

        :return: The target_number_connections of this AgentConnectorTransportStats.  # noqa: E501
        :rtype: int
        """
        return self._target_number_connections

    @target_number_connections.setter
    def target_number_connections(self, target_number_connections):
        """Sets the target_number_connections of this AgentConnectorTransportStats.

        The number of connections which should be in an active state. Note that this may be less than active_connections if the AgentConnector is currently applying configuration changes. It may be more than active_connections if there is a connectivity issue, or connections are first starting.   # noqa: E501

        :param target_number_connections: The target_number_connections of this AgentConnectorTransportStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and target_number_connections is None:  # noqa: E501
            raise ValueError("Invalid value for `target_number_connections`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                target_number_connections is not None and target_number_connections < 0):  # noqa: E501
            raise ValueError("Invalid value for `target_number_connections`, must be a value greater than or equal to `0`")  # noqa: E501

        self._target_number_connections = target_number_connections

    @property
    def connection_start_count(self):
        """Gets the connection_start_count of this AgentConnectorTransportStats.  # noqa: E501

        The number of times connections have been started   # noqa: E501

        :return: The connection_start_count of this AgentConnectorTransportStats.  # noqa: E501
        :rtype: int
        """
        return self._connection_start_count

    @connection_start_count.setter
    def connection_start_count(self, connection_start_count):
        """Sets the connection_start_count of this AgentConnectorTransportStats.

        The number of times connections have been started   # noqa: E501

        :param connection_start_count: The connection_start_count of this AgentConnectorTransportStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and connection_start_count is None:  # noqa: E501
            raise ValueError("Invalid value for `connection_start_count`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connection_start_count is not None and connection_start_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `connection_start_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._connection_start_count = connection_start_count

    @property
    def connection_stop_count(self):
        """Gets the connection_stop_count of this AgentConnectorTransportStats.  # noqa: E501

        The number of times connections have stopped   # noqa: E501

        :return: The connection_stop_count of this AgentConnectorTransportStats.  # noqa: E501
        :rtype: int
        """
        return self._connection_stop_count

    @connection_stop_count.setter
    def connection_stop_count(self, connection_stop_count):
        """Sets the connection_stop_count of this AgentConnectorTransportStats.

        The number of times connections have stopped   # noqa: E501

        :param connection_stop_count: The connection_stop_count of this AgentConnectorTransportStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and connection_stop_count is None:  # noqa: E501
            raise ValueError("Invalid value for `connection_stop_count`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connection_stop_count is not None and connection_stop_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `connection_stop_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._connection_stop_count = connection_stop_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorTransportStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorTransportStats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class RenderedRule(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'methods': 'list[str]',
        'paths': 'list[str]',
        'query_parameters': 'list[RenderedQueryParameter]',
        'body': 'RenderedRuleBody',
        'resource_info': 'ResourceInfo'
    }

    attribute_map = {
        'methods': 'methods',
        'paths': 'paths',
        'query_parameters': 'query_parameters',
        'body': 'body',
        'resource_info': 'resource_info'
    }

    def __init__(self, methods=None, paths=None, query_parameters=None, body=None, resource_info=None, local_vars_configuration=None):  # noqa: E501
        """RenderedRule - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._methods = None
        self._paths = None
        self._query_parameters = None
        self._body = None
        self._resource_info = None
        self.discriminator = None

        if methods is not None:
            self.methods = methods
        if paths is not None:
            self.paths = paths
        if query_parameters is not None:
            self.query_parameters = query_parameters
        if body is not None:
            self.body = body
        if resource_info is not None:
            self.resource_info = resource_info

    @property
    def methods(self):
        """Gets the methods of this RenderedRule.  # noqa: E501

        The HTTP method to allow.  # noqa: E501

        :return: The methods of this RenderedRule.  # noqa: E501
        :rtype: list[str]
        """
        return self._methods

    @methods.setter
    def methods(self, methods):
        """Sets the methods of this RenderedRule.

        The HTTP method to allow.  # noqa: E501

        :param methods: The methods of this RenderedRule.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["get", "put", "post", "delete", "head", "options", "connect", "trace", "patch", "copy", "lock", "mkcol", "move", "propfind", "proppatch", "unlock", "all"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(methods).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `methods` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(methods) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._methods = methods

    @property
    def paths(self):
        """Gets the paths of this RenderedRule.  # noqa: E501

        regex for HTTP path  # noqa: E501

        :return: The paths of this RenderedRule.  # noqa: E501
        :rtype: list[str]
        """
        return self._paths

    @paths.setter
    def paths(self, paths):
        """Sets the paths of this RenderedRule.

        regex for HTTP path  # noqa: E501

        :param paths: The paths of this RenderedRule.  # noqa: E501
        :type: list[str]
        """

        self._paths = paths

    @property
    def query_parameters(self):
        """Gets the query_parameters of this RenderedRule.  # noqa: E501

        A set of constraints on the parameters contained in the query string.  # noqa: E501

        :return: The query_parameters of this RenderedRule.  # noqa: E501
        :rtype: list[RenderedQueryParameter]
        """
        return self._query_parameters

    @query_parameters.setter
    def query_parameters(self, query_parameters):
        """Sets the query_parameters of this RenderedRule.

        A set of constraints on the parameters contained in the query string.  # noqa: E501

        :param query_parameters: The query_parameters of this RenderedRule.  # noqa: E501
        :type: list[RenderedQueryParameter]
        """

        self._query_parameters = query_parameters

    @property
    def body(self):
        """Gets the body of this RenderedRule.  # noqa: E501


        :return: The body of this RenderedRule.  # noqa: E501
        :rtype: RenderedRuleBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this RenderedRule.


        :param body: The body of this RenderedRule.  # noqa: E501
        :type: RenderedRuleBody
        """

        self._body = body

    @property
    def resource_info(self):
        """Gets the resource_info of this RenderedRule.  # noqa: E501


        :return: The resource_info of this RenderedRule.  # noqa: E501
        :rtype: ResourceInfo
        """
        return self._resource_info

    @resource_info.setter
    def resource_info(self, resource_info):
        """Sets the resource_info of this RenderedRule.


        :param resource_info: The resource_info of this RenderedRule.  # noqa: E501
        :type: ResourceInfo
        """

        self._resource_info = resource_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RenderedRule):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RenderedRule):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.26
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class CreateTokenRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sub': 'str',
        'org': 'str',
        'roles': 'dict(str, str)',
        'audiences': 'list[str]',
        'time_validity': 'TimeValidity',
        'hosts': 'list[HostPermissions]',
        'token_validity': 'TokenValidity',
        'session': 'str',
        'scopes': 'list[str]'
    }

    attribute_map = {
        'sub': 'sub',
        'org': 'org',
        'roles': 'roles',
        'audiences': 'audiences',
        'time_validity': 'time_validity',
        'hosts': 'hosts',
        'token_validity': 'token_validity',
        'session': 'session',
        'scopes': 'scopes'
    }

    def __init__(self, sub=None, org=None, roles=None, audiences=None, time_validity=None, hosts=None, token_validity=None, session=None, scopes=None, local_vars_configuration=None):  # noqa: E501
        """CreateTokenRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sub = None
        self._org = None
        self._roles = None
        self._audiences = None
        self._time_validity = None
        self._hosts = None
        self._token_validity = None
        self._session = None
        self._scopes = None
        self.discriminator = None

        self.sub = sub
        self.org = org
        if roles is not None:
            self.roles = roles
        self.audiences = audiences
        self.time_validity = time_validity
        if hosts is not None:
            self.hosts = hosts
        if token_validity is not None:
            self.token_validity = token_validity
        if session is not None:
            self.session = session
        if scopes is not None:
            self.scopes = scopes

    @property
    def sub(self):
        """Gets the sub of this CreateTokenRequest.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The sub of this CreateTokenRequest.  # noqa: E501
        :rtype: str
        """
        return self._sub

    @sub.setter
    def sub(self, sub):
        """Sets the sub of this CreateTokenRequest.

        Unique identifier  # noqa: E501

        :param sub: The sub of this CreateTokenRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sub is None:  # noqa: E501
            raise ValueError("Invalid value for `sub`, must not be `None`")  # noqa: E501

        self._sub = sub

    @property
    def org(self):
        """Gets the org of this CreateTokenRequest.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org of this CreateTokenRequest.  # noqa: E501
        :rtype: str
        """
        return self._org

    @org.setter
    def org(self, org):
        """Sets the org of this CreateTokenRequest.

        Unique identifier  # noqa: E501

        :param org: The org of this CreateTokenRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org is None:  # noqa: E501
            raise ValueError("Invalid value for `org`, must not be `None`")  # noqa: E501

        self._org = org

    @property
    def roles(self):
        """Gets the roles of this CreateTokenRequest.  # noqa: E501

        associative mapping of an application to a role  # noqa: E501

        :return: The roles of this CreateTokenRequest.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this CreateTokenRequest.

        associative mapping of an application to a role  # noqa: E501

        :param roles: The roles of this CreateTokenRequest.  # noqa: E501
        :type: dict(str, str)
        """

        self._roles = roles

    @property
    def audiences(self):
        """Gets the audiences of this CreateTokenRequest.  # noqa: E501

        array of audiences  # noqa: E501

        :return: The audiences of this CreateTokenRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._audiences

    @audiences.setter
    def audiences(self, audiences):
        """Sets the audiences of this CreateTokenRequest.

        array of audiences  # noqa: E501

        :param audiences: The audiences of this CreateTokenRequest.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and audiences is None:  # noqa: E501
            raise ValueError("Invalid value for `audiences`, must not be `None`")  # noqa: E501

        self._audiences = audiences

    @property
    def time_validity(self):
        """Gets the time_validity of this CreateTokenRequest.  # noqa: E501


        :return: The time_validity of this CreateTokenRequest.  # noqa: E501
        :rtype: TimeValidity
        """
        return self._time_validity

    @time_validity.setter
    def time_validity(self, time_validity):
        """Sets the time_validity of this CreateTokenRequest.


        :param time_validity: The time_validity of this CreateTokenRequest.  # noqa: E501
        :type: TimeValidity
        """
        if self.local_vars_configuration.client_side_validation and time_validity is None:  # noqa: E501
            raise ValueError("Invalid value for `time_validity`, must not be `None`")  # noqa: E501

        self._time_validity = time_validity

    @property
    def hosts(self):
        """Gets the hosts of this CreateTokenRequest.  # noqa: E501

        array of valid hosts  # noqa: E501

        :return: The hosts of this CreateTokenRequest.  # noqa: E501
        :rtype: list[HostPermissions]
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """Sets the hosts of this CreateTokenRequest.

        array of valid hosts  # noqa: E501

        :param hosts: The hosts of this CreateTokenRequest.  # noqa: E501
        :type: list[HostPermissions]
        """

        self._hosts = hosts

    @property
    def token_validity(self):
        """Gets the token_validity of this CreateTokenRequest.  # noqa: E501


        :return: The token_validity of this CreateTokenRequest.  # noqa: E501
        :rtype: TokenValidity
        """
        return self._token_validity

    @token_validity.setter
    def token_validity(self, token_validity):
        """Sets the token_validity of this CreateTokenRequest.


        :param token_validity: The token_validity of this CreateTokenRequest.  # noqa: E501
        :type: TokenValidity
        """

        self._token_validity = token_validity

    @property
    def session(self):
        """Gets the session of this CreateTokenRequest.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The session of this CreateTokenRequest.  # noqa: E501
        :rtype: str
        """
        return self._session

    @session.setter
    def session(self, session):
        """Sets the session of this CreateTokenRequest.

        Unique identifier  # noqa: E501

        :param session: The session of this CreateTokenRequest.  # noqa: E501
        :type: str
        """

        self._session = session

    @property
    def scopes(self):
        """Gets the scopes of this CreateTokenRequest.  # noqa: E501

        The list of scopes requested for the access token. Multiple scopes are seperated by a space character. Ex. urn:agilicus:users urn:agilicus:issuers. An optional is specified with an ? at the end. Optional scopes are used when the permission is requested but not required. Ex. urn:agilicus:users?  # noqa: E501

        :return: The scopes of this CreateTokenRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._scopes

    @scopes.setter
    def scopes(self, scopes):
        """Sets the scopes of this CreateTokenRequest.

        The list of scopes requested for the access token. Multiple scopes are seperated by a space character. Ex. urn:agilicus:users urn:agilicus:issuers. An optional is specified with an ? at the end. Optional scopes are used when the permission is requested but not required. Ex. urn:agilicus:users?  # noqa: E501

        :param scopes: The scopes of this CreateTokenRequest.  # noqa: E501
        :type: list[str]
        """

        self._scopes = scopes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTokenRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateTokenRequest):
            return True

        return self.to_dict() != other.to_dict()
